@@ -40,9 +40,6 @@
 #include "Settings.h"
 #include "Updater.h"
 #include "Widgets/ProgressInfoWindow.h"
-#ifndef gmic_core
-#include "CImg.h"
-#endif
 #include "gmic.h"
 
 #ifdef _IS_WINDOWS_
@@ -59,7 +56,7 @@ namespace GmicQt
  * @param parent
  */
 HeadlessProcessor::HeadlessProcessor(QObject * parent) //
-    : QObject(parent), _filterThread(nullptr), _gmicImages(new cimg_library::CImgList<gmic_pixel_type>)
+    : QObject(parent), _filterThread(nullptr), _gmicImages(new gmic_library::gmic_list<gmic_pixel_type>)
 {
   _progressWindow = nullptr;
   _processingCompletedProperly = false;
