@@ -1,5 +1,7 @@
 <?xml version="1.0" encoding="utf-8"?>
+
 <!-- Original traditional Chinese translation done by ZX-WT (https://github.com/ZX-WT) -->
+
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
 <context>
@@ -10,12 +12,12 @@
         <translation>對話框</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="221"/>
+        <location filename="../ui/dialogsettings.ui" line="238"/>
         <source>Internet updates</source>
         <translation>網際網路更新</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="230"/>
+        <location filename="../ui/dialogsettings.ui" line="247"/>
         <source>Update now</source>
         <translation>立即更新</translation>
     </message>
@@ -75,23 +77,33 @@
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;（警告：啟用時預覽或會不準確。）&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="215"/>
+        <location filename="../ui/dialogsettings.ui" line="196"/>
+        <source>Misc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="209"/>
+        <source>&amp;Enable High-DPI support</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="216"/>
+        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
+        <translation type="unfinished">&lt;i&gt;（需要重啟程式）&lt;/i&gt;</translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="232"/>
         <source>Other</source>
         <translation>其他</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="253"/>
+        <location filename="../ui/dialogsettings.ui" line="270"/>
         <source>Output messages</source>
         <translation>輸出訊息</translation>
     </message>
-    <message>
-        <location filename="../ui/dialogsettings.ui" line="196"/>
-        <source>Dialogs</source>
-        <translation>對話框</translation>
-    </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="202"/>
-        <source>Use native color dialog</source>
+        <source>&amp;Use native color dialog</source>
         <translation>使用系統原生色彩對話框</translation>
     </message>
     <message>
@@ -110,12 +122,12 @@
         <translation>顯示機構標誌</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="262"/>
+        <location filename="../ui/dialogsettings.ui" line="279"/>
         <source>Notify when scheduled update fails</source>
         <translation>在定期更新失敗時通知</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="304"/>
+        <location filename="../ui/dialogsettings.ui" line="321"/>
         <source>&amp;Ok</source>
         <translation>確定(&amp;O)</translation>
     </message>
@@ -255,12 +267,12 @@
 <context>
     <name>GmicQt::FiltersPresenter</name>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="498"/>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="499"/>
         <source>Unknown filter</source>
         <translation>不明的濾鏡</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="607"/>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="609"/>
         <source>Cannot find this fave&apos;s original filter
 </source>
         <translation>找不到這最愛濾鏡的來源濾鏡
@@ -337,12 +349,12 @@
 <context>
     <name>GmicQt::GmicProcessor</name>
     <message>
-        <location filename="../src/GmicProcessor.cpp" line="339"/>
+        <location filename="../src/GmicProcessor.cpp" line="345"/>
         <source>Image #%1 returned by filter has %2 channels (should be at most 4)</source>
         <translation>濾鏡傳回的影像 #%1 含有 %2 個通道（應為不多於 4 個）</translation>
     </message>
     <message>
-        <location filename="../src/GmicProcessor.cpp" line="373"/>
+        <location filename="../src/GmicProcessor.cpp" line="380"/>
         <source>Image #%1 returned by filter has %2 channels
 (should be at most 4)</source>
         <translation>濾鏡傳回的影像 #%1 含有 %2 個通道
@@ -352,22 +364,22 @@
 <context>
     <name>GmicQt::HeadlessProcessor</name>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="80"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="84"/>
         <source>At least a filter path or a filter command must be provided.</source>
         <translation>必須提供濾鏡路徑或濾鏡命令。</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="82"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="86"/>
         <source>Custom command (%1)</source>
         <translation>自訂命令 (%1)</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="90"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="94"/>
         <source>Cannot find filter matching path %1</source>
         <translation>找不到符合路徑「%1」的濾鏡</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="97"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="101"/>
         <source>Error parsing filter parameters definition for filter:
 
 %1
@@ -384,17 +396,17 @@ Cannot retrieve default parameters.
 %2</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="115"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="119"/>
         <source>Error parsing supplied command: %1</source>
         <translation>解析所提供的命令時出現錯誤：%1</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="118"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="122"/>
         <source>Supplied command (%1) does not match path (%2), (should be %3).</source>
         <translation>所提供的命令 (%1) 不符合路徑 (%2)（應為 %3）。</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="232"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="234"/>
         <source>Filter execution failed, but with no error message.</source>
         <translation>濾鏡執行失敗，但沒有錯誤訊息。</translation>
     </message>
@@ -498,76 +510,76 @@ Cannot retrieve default parameters.
 <context>
     <name>GmicQt::MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="110"/>
+        <location filename="../src/MainWindow.cpp" line="115"/>
         <source>Add fave</source>
         <translation>加到最愛</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="112"/>
+        <location filename="../src/MainWindow.cpp" line="117"/>
         <source>Reset parameters to default values</source>
         <translation>重設參數到預設值</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="118"/>
+        <location filename="../src/MainWindow.cpp" line="123"/>
         <source>Copy G&apos;MIC command to clipboard</source>
         <translation>複製 G&apos;MIC 命令到剪貼簿</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="125"/>
+        <location filename="../src/MainWindow.cpp" line="130"/>
         <source>Rename fave</source>
         <translation>重新命名最愛</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="127"/>
+        <location filename="../src/MainWindow.cpp" line="132"/>
         <source>Remove fave</source>
         <translation>從最愛移除</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="131"/>
+        <location filename="../src/MainWindow.cpp" line="136"/>
         <source>Expand/Collapse all</source>
         <translation>全部展開或折疊</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="133"/>
+        <location filename="../src/MainWindow.cpp" line="138"/>
         <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
         <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;諾曼第大學 (https://www.unicaen.fr)&lt;br/&gt;ENSICAEN (https://www.ensicaen.fr)</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="140"/>
+        <location filename="../src/MainWindow.cpp" line="145"/>
         <source>Selection mode</source>
         <translation>選取模式</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="178"/>
+        <location filename="../src/MainWindow.cpp" line="183"/>
         <source>Update filters</source>
         <translation>更新濾鏡</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="232"/>
+        <location filename="../src/MainWindow.cpp" line="237"/>
         <source>Manage visible tags
 (Right-click on a fave or a filter to set/remove tags)</source>
         <translation>管理可見標籤
 （右鍵點選最愛或濾鏡，以設定或移除標籤）</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="354"/>
+        <location filename="../src/MainWindow.cpp" line="359"/>
         <source>Update completed</source>
         <translation>更新完成</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="354"/>
-        <location filename="../src/MainWindow.cpp" line="356"/>
-        <location filename="../src/MainWindow.cpp" line="477"/>
+        <location filename="../src/MainWindow.cpp" line="359"/>
+        <location filename="../src/MainWindow.cpp" line="361"/>
+        <location filename="../src/MainWindow.cpp" line="493"/>
         <source>Filter definitions have been updated.</source>
         <translation>濾鏡定義已更新。</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="359"/>
+        <location filename="../src/MainWindow.cpp" line="364"/>
         <source>No download was needed.</source>
         <translation>無需下載。</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="412"/>
+        <location filename="../src/MainWindow.cpp" line="417"/>
         <source>Plugin was called with a filter path with no matching filter:
 
 Path: %1</source>
@@ -576,8 +588,8 @@ Path: %1</source>
 路徑為：%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="420"/>
-        <location filename="../src/MainWindow.cpp" line="447"/>
+        <location filename="../src/MainWindow.cpp" line="425"/>
+        <location filename="../src/MainWindow.cpp" line="452"/>
         <source>Error parsing filter parameters definition for filter:
 
 %1
@@ -594,7 +606,7 @@ Cannot retrieve default parameters.
 %2</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="433"/>
+        <location filename="../src/MainWindow.cpp" line="438"/>
         <source>Plugin was called with a command that cannot be recognized as a filter:
 
 Command: %1</source>
@@ -603,7 +615,7 @@ Command: %1</source>
 命令：%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="428"/>
+        <location filename="../src/MainWindow.cpp" line="433"/>
         <source>Plugin was called with a command that cannot be parsed:
 
 %1</source>
@@ -612,7 +624,7 @@ Command: %1</source>
 %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="437"/>
+        <location filename="../src/MainWindow.cpp" line="442"/>
         <source>Plugin was called with a command that does not match the provided path:
 
 Path: %1
@@ -625,52 +637,52 @@ Command found for this path : %3</source>
 路徑中找到的命令：%3</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="473"/>
+        <location filename="../src/MainWindow.cpp" line="489"/>
         <source>Filters update could not be achieved</source>
         <translation>無法完成濾鏡更新</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="599"/>
+        <location filename="../src/MainWindow.cpp" line="615"/>
         <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
         <translation>由於發生以下錯誤，&lt;br&gt;無法完成更新：&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="605"/>
+        <location filename="../src/MainWindow.cpp" line="621"/>
         <source>Update error</source>
         <translation>更新錯誤</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="808"/>
+        <location filename="../src/MainWindow.cpp" line="810"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="904"/>
+        <location filename="../src/MainWindow.cpp" line="925"/>
         <source>Waiting for cancelled jobs...</source>
         <translation>正在等待取消工作……</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1277"/>
+        <location filename="../src/MainWindow.cpp" line="1291"/>
         <source>Import faves</source>
         <translation>匯入最愛</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1277"/>
+        <location filename="../src/MainWindow.cpp" line="1291"/>
         <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
         <translation>你要從以下檔案匯入最愛嗎？&lt;br/&gt;%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1280"/>
+        <location filename="../src/MainWindow.cpp" line="1294"/>
         <source>Don&apos;t ask again</source>
         <translation>不再詢問</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1392"/>
+        <location filename="../src/MainWindow.cpp" line="1406"/>
         <source>Confirmation</source>
         <translation>確認</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1392"/>
+        <location filename="../src/MainWindow.cpp" line="1406"/>
         <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
         <translation>一項 gmic 命令正在執行中。&lt;br&gt;你確定要關閉外掛程式嗎？</translation>
     </message>
@@ -715,22 +727,22 @@ Command found for this path : %3</source>
 <context>
     <name>GmicQt::ProgressInfoWindow</name>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="49"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="52"/>
         <source>G&apos;MIC-Qt Plug-in progression</source>
         <translation>G&apos;MIC-Qt 外掛程式進度</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="141"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="144"/>
         <source>%1 seconds</source>
         <translation>%1 秒</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="151"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="154"/>
         <source>[Processing %1 | %2]</source>
         <translation>[正在處理 %1 | %2]</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="153"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="156"/>
         <source>[Processing %1]</source>
         <translation>[正在處理 %1]</translation>
     </message>
@@ -751,27 +763,27 @@ Command found for this path : %3</source>
 <context>
     <name>GmicQt::Updater</name>
     <message>
-        <location filename="../src/Updater.cpp" line="199"/>
+        <location filename="../src/Updater.cpp" line="202"/>
         <source>Error downloading %1 (empty file?)</source>
         <translation>下載「%1」時出現錯誤（空白檔案？）</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="208"/>
+        <location filename="../src/Updater.cpp" line="211"/>
         <source>Could not read/decompress %1</source>
         <translation>不能讀取或解壓縮「%1」</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="213"/>
+        <location filename="../src/Updater.cpp" line="216"/>
         <source>Error writing file %1</source>
         <translation>寫入檔案「%1」時出現錯誤</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="230"/>
+        <location filename="../src/Updater.cpp" line="233"/>
         <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
         <translation>下載「%1」時出現錯誤&lt;br/&gt;錯誤 %2：%3</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="266"/>
+        <location filename="../src/Updater.cpp" line="269"/>
         <source>Download timeout: %1</source>
         <translation>下載逾時：%1</translation>
     </message>
@@ -807,7 +819,7 @@ Command found for this path : %3</source>
         <translation>重設縮放比例</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="155"/>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="154"/>
         <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
         <translation>警告：預覽可能不準確（縮放比例已修改）</translation>
     </message>
@@ -1032,27 +1044,27 @@ Command found for this path : %3</source>
         <translation>可見</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="103"/>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="104"/>
         <source>Available filters (%1)</source>
         <translation>可用的濾鏡 (%1)</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="74"/>
+        <location filename="../src/Host/None/host_none.cpp" line="77"/>
         <source>Select an image to open...</source>
         <translation>開啟影像…</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="80"/>
+        <location filename="../src/Host/None/host_none.cpp" line="83"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="80"/>
+        <location filename="../src/Host/None/host_none.cpp" line="83"/>
         <source>Could not open file.</source>
         <translation>無法開啟檔案。</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="84"/>
+        <location filename="../src/Host/None/host_none.cpp" line="87"/>
         <source>Default image</source>
         <translation>預設影像</translation>
     </message>
@@ -1107,7 +1119,7 @@ Command found for this path : %3</source>
         <translation>無法載入翻譯檔「%1」</translation>
     </message>
     <message>
-        <location filename="../src/Misc.cpp" line="330"/>
+        <location filename="../src/Misc.cpp" line="333"/>
         <source>List %1 cannot be merged considering these runs: %2</source>
         <translation>無法合併清單 %1，關聯的執行次：%2</translation>
     </message>
@@ -1131,27 +1143,27 @@ Command found for this path : %3</source>
 <context>
     <name>gmic_qt_standalone::ImageDialog</name>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="71"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="74"/>
         <source>G&apos;MIC-Qt filter output</source>
         <translation>G&apos;MIC-Qt 濾鏡輸出</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="82"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="85"/>
         <source>Close</source>
         <translation>關閉</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="85"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="88"/>
         <source>Save as...</source>
         <translation>另存為…</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="120"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="123"/>
         <source>%1 file (*.%2)</source>
         <translation>%1 檔 (*.%2)</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="141"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="144"/>
         <source>Save image as...</source>
         <translation>儲存影像為…</translation>
     </message>
@@ -1159,12 +1171,12 @@ Command found for this path : %3</source>
 <context>
     <name>gmic_qt_standalone::ImageView</name>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="63"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="66"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="63"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="66"/>
         <source>Could not write image file %1</source>
         <translation>無法寫入影像檔「%1」</translation>
     </message>
